# psychopy-visionscience

Plugin package for PsychoPy which adds stimuli useful for vision science.

## Features

Installing this package alongside PsychoPy will add the following visual stimuli:

* Noise patch (`psychopy.visual.NoiseStim` and Builder component)
* Second-order gratings with envelope (`psychopy.visual.EnvelopeGrating` and Builder component)
    
## Installing

Install this package with the following shell command:: 

    pip install psychopy-visionscience

You may also use PsychoPy's builtin package manager to install this package.